'use strict';

var _meow = require('meow');

var _meow2 = _interopRequireDefault(_meow);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cli = (0, _meow2.default)({
  pkg: './../package.json',
  help: ['Usage', '  dictionary <lang-from> <lang-to> <input>', '', '  # if input match /[a-zA-Z]/ it will translate from english to <lang>, otherwise from <lang> to english', '  dictionary --en=<lang> <input>', '  # if input match /[а-яА-Я]/ it will translate from russian to <lang>, otherwise from <lang> to russian', '  dictionary --ru=<lang> <input>', '', '  dictionary <lang> --export', '  dictionary <lang> --export > history.txt']
});

var print = console.log.bind(console);

var fromLang = void 0;
var toLang = void 0;
var input = void 0;

var setupLangs = function setupLangs(lang, regEx) {
  input = cli.input.join(' ');

  if (regEx.test(input)) {
    fromLang = lang;
    toLang = cli.flags[lang];
  } else {
    fromLang = cli.flags[lang];
    toLang = lang;
  }
};

if (cli.flags.en) {
  setupLangs('en', /[a-zA-Z]+/);
} else if (cli.flags.ru) {
  setupLangs('ru', /[а-яА-Я]+/);
} else {
  input = cli.input.slice(2).join(' ');
}

if (cli.flags.export && cli.input.length !== 1 || !cli.flags.export && input.length === 0) {
  cli.showHelp();
} else {
  (function () {
    fromLang = fromLang || cli.input[0];
    toLang = toLang || cli.input[1];

    var lib = require('./index');
    var space = require('lodash/repeat').bind(null, ' ');
    var u = _chalk2.default.underline;

    lib.translate(fromLang, toLang, input).then(function (_ref) {
      var type = _ref.type;
      var result = _ref.result;
      var corrected = _ref.corrected;

      if (corrected) {
        print('\nnothing found by "' + u(input) + '", corrected to "' + u(corrected) + '"\n');
      }

      if (type === 'dictionary') {
        (function () {
          var printTranslations = function printTranslations(r) {
            print(space(2) + '- ' + u(r.translation) + ' ' + (r.synonyms ? r.synonyms + ' ' : '') + r.means);
            r.examples.forEach(function (r) {
              return print(space(4) + '-- ' + r.title);
            });
          };

          result.forEach(function (r) {
            print(u(r.pos) + ' ' + (r.ts ? '(' + r.ts + ')' : ''));
            r.translations.forEach(printTranslations);
          });
        })();
      } else {
        print(result);
      }
    }).catch(function (err) {
      if (err.message === 'no translation') {
        console.log('no translation');
      } else {
        throw err;
      }
    });
  })();
}