'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.translate = undefined;

var _yandex = require('./yandex');

var _yandex2 = _interopRequireDefault(_yandex);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var translateKey = 'trnsl.1.1.20131018T175412Z.6e9fa29e525b4697.3542f82ffa6916d1ccd64201d8a72c023892ae5e';
var dictionaryKey = 'dict.1.1.20140616T070444Z.ecfe60ba07dd3ebc.9ce897a05d9daa488b050e5ec030f625d666530a';

var yandex = new _yandex2.default(process.env.YANDEX_TRANSLATE_KEY || translateKey, process.env.YANDEX_DICTIONARY_KEY || dictionaryKey);

var translate = exports.translate = function translate(fromLang, toLang, text) {
  var corrected = arguments.length <= 3 || arguments[3] === undefined ? null : arguments[3];

  var translateFn = function translateFn(text) {
    return yandex.translate(fromLang, toLang, text);
  };
  var translateFallback = function translateFallback() {
    return translateFn(text).then(function (translation) {
      if (translation === text && !corrected) {
        var onSpellResult = function onSpellResult(spellResult) {
          if (spellResult === text) {
            return { type: 'translate', result: translation, corrected: corrected };
          } else {
            return translate(fromLang, toLang, spellResult, spellResult);
          }
        };

        return yandex.spellCheck(fromLang, text).then(onSpellResult);
      } else {
        return { type: 'translate', result: translation, corrected: corrected };
      }
    });
  };

  var dictionary = function dictionary() {
    return yandex.dictionary(fromLang, toLang, text).then(function (result) {
      if (result.length === 0) {
        return translateFallback();
      } else {
        return { type: 'dictionary', result: formatDictionary(result), corrected: corrected };
      }
    });
  };

  return dictionary().then(null, translateFallback);
};

var joiner = function joiner(array) {
  return array.length > 0 ? '(' + array.join(' | ') + ')' : '';
};

var formatDictionaryTranslations = function formatDictionaryTranslations(translation) {
  var synonyms = (translation.syn || []).map(function (syn) {
    return syn.text;
  });
  var means = (translation.mean || []).map(function (means) {
    return means.text;
  });

  return {
    translation: translation.text,
    synonyms: joiner(synonyms),
    means: joiner(means),
    examples: (translation.ex || []).map(function (ex) {
      var translations = ex.tr.map(function (_) {
        return _.text;
      });

      return {
        title: ex.text + ' ' + joiner(translations),
        text: ex.text,
        translations: translations
      };
    })
  };
};

var formatDictionary = function formatDictionary(result) {
  return result.map(function (word) {
    return {
      title: word.pos + ' (' + word.ts + ')',
      pos: word.pos,
      ts: word.ts,
      translations: word.tr.map(formatDictionaryTranslations)
    };
  });
};